Getters
--------------------------------------------------

asent.getters
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: asent.getters
   :members:
   :undoc-members:
   :show-inheritance:
   :exclude-members: normalize, questionmark_amplification, exclamation_amplification, but_check, sift_sentiment_scores

